/*!
 * \file mock_classify.cpp
 * \brief A mock classify class to test the cba package.
 *
 * mock_classify is a test classify class for the cba package.
 *
 * \author Russell Toris, WPI - rctoris@wpi.edu
 * \date November 22, 2011
 */

#include <lfd_common/state.h>
#include <ros/ros.h>
#include <time.h>

using namespace std;

/*!
 * Creates and runs the mock_state_publisher node.
 *
 * \param argc argument count that is passed to ros::init
 * \param argv arguments that are passed to ros::init
 * \return EXIT_SUCCESS if the node runs correctly
 */
int main(int argc, char **argv)
{
  // initialize ROS and the node
  ros::init(argc, argv, "mock_state_publisher");
  // a handle for this ROS node
  ros::NodeHandle node;

  // published topics
  ros::Publisher update_state = node.advertise<lfd_common::state> ("state_listener", 1);

  // used to create random states
  srand(time(NULL));

  ROS_INFO("Mock State Publisher Initialized");

  // publish states continuously
  while (ros::ok())
  {
    // 3 dimensional state vector all in range [0,25)
    lfd_common::state s;
    for (int i = 0; i < 3; i++)
      s .state_vector.push_back(rand() % 25);
    update_state.publish(s);
    ros::spinOnce();
  }

  return EXIT_SUCCESS;
}
